.. AUTO-GENERATED FILE -- DO NOT EDIT!

utils.initthreads
=================

Module: :mod:`utils.initthreads`
--------------------------------
.. automodule:: zmq.utils.initthreads

.. currentmodule:: zmq.utils.initthreads

.. autofunction:: zmq.utils.initthreads.init_threads

